


       /***********************************************
       *
       *       file d:\cips\cips.c
       *
       *       Functions: This file contains
       *          main
       *          clear_text_screen
       *          show_menu
       *          show_image
       *
       *       Purpose:
       *          This file contains the main calling
       *          routine in the C Image Processing System.
       *
       *       External Calls:
       *          numcvrt.c - get_integer
       *          gin.c - get_image_name
       *          rtiff.c - read_tiff_image
       *          tiff.c - read_tiff_header
       *          rstring.c - read_string
       *          display.c - display_image
       *                      display_menu_for_display_image
       *          pi.c - print_image
       *          ht.c - display_using_halftoning
       *                 get_threshold_value
       *          djet.c - print_graphics_image
       *                   get_graphics_caption
       *          hist.c - display_menu_for_histogram
       *                   calculate_area_histogram
       *                   print_histogram
       *                   show_histogram
       *          edge.c - detect_edges
       *                   get_edge_options
       *                   quick_edge
       *
       *       Modifications:
       *          26 June 1990 - created
       *
       *************************************************/

#include "d:\cips\cips.h"


short the_image[ROWS][COLS];
short out_image[ROWS][COLS];

main()
{

   char caption[80],
        color_transform[80],
        monitor_type[80],
        name[80],
        name2[80],
        rep[80];


   int  color,
        detect_threshold,
        detect_type,
        display_colors,
        file_d,
        first_element,
        first_line,
        high,
        horizontal,
        i,
        ie,
        il,
        image_colors,
        invert,
        j,
        le,
        ll,
        not_finished,
        print,
        response,
        show_hist,
        threshold,
        vertical;

   long     mean_of_pixels;
   unsigned long histogram[256];
   struct   tiff_header_struct image_header;


   clear_text_screen();


   not_finished   =  1;
   response       = 99;

   il             = 1;
   ie             = 1;
   ll             = ROWS+1;
   le             = COLS+1;

   print          =   0;
   threshold      = 128;
   detect_type    =   1;
   display_colors =  16;
   image_colors   = 256;
   invert         =   0;
   vertical       =   3;
   horizontal     =   3;
   show_hist      =   0;
   high           = 100;
   detect_threshold = 1;
   strcpy(color_transform, "Straight mode");
   strcpy(monitor_type, "VGA");


   strcpy(name,  "d:/pix/adam256.tif");
   strcpy(name2, "d:/pix/output.tif");

     while(not_finished){

        show_menu();

        get_integer(&response);

        switch (response){

        case 1:/* display image header */
         get_image_name(name);
         read_tiff_header(name, &image_header);
         printf("\n\nCIPS> The image header is:");
         printf("\n\t\twidth=%ld length=%ld  start=%ld  bits=%ld",
              image_header.image_width,
              image_header.image_length,
              image_header.strip_offset,
              image_header.bits_per_pixel);
         printf("\nCIPS> Hit Enter to continue");
         read_string(rep);
        break;

        case 2:/* display image numbers */
         get_image_name(name);
         get_parameters(&il, &ie, &ll, &le);
         read_tiff_image(name, the_image, il, ie, ll, le);
         show_image(the_image, il, ie);
         break;

        case 3:   /* print image numbers */
         get_image_name(name);
         get_parameters(&il, &ie, &ll, &le);
         read_tiff_image(name, the_image, il, ie, ll, le);
         print_image(the_image, name, 1, 1, 1, 100, 18,
                     il, ie);
        break;

        case 4:   /* display image */
         get_image_name(name);
         read_tiff_header(name, &image_header);
         get_parameters(&il, &ie, &ll, &le);
         display_menu_for_display_image(&image_colors,
                   &display_colors, &invert,
                   color_transform, monitor_type,
                   &show_hist);
         display_image(name, the_image, il, ie,
                   ll, le, &image_header, monitor_type,
                   color_transform, invert,
                   image_colors, display_colors, show_hist);
        break;

        case 5:   /* display image using halftoning */
         get_image_name(name);
         read_tiff_header(name, &image_header);
         get_parameters(&il, &ie, &ll, &le);
         display_menu_for_display_image(&image_colors,
                   &display_colors, &invert,
                   color_transform, monitor_type,
                   &show_hist);
         get_threshold_value(&threshold, &print);
         display_using_halftoning(the_image, name,
                   il, ie, ll, le, threshold,
                   invert, image_colors, &image_header,
                   monitor_type, print, show_hist,
                   color_transform);
        break;

        case 6:   /* print graphics image */
         get_image_name(name);
         read_tiff_header(name, &image_header);
         get_parameters(&il, &ie, &ll, &le);
         display_menu_for_display_image(&image_colors,
                   &display_colors, &invert,
                   color_transform, monitor_type,
                   &show_hist);
         get_graphics_caption(caption);
         print_graphics_image(the_image, out_image, name,
                   il, ie, ll, le, image_colors,
                   invert, caption, show_hist,
                   color_transform);
        break;

        case 7:   /* print or display histogram numbers */
         get_image_name(name);
         read_tiff_header(name, &image_header);
         get_parameters(&il, &ie, &ll, &le);
         display_menu_for_histogram(&print, &vertical,
                   &horizontal);
         calculate_area_histogram(histogram, vertical,
                   horizontal, the_image, name,
                   il, ie, ll, le);
         if(print == 0)
            show_histogram(histogram);
         if(print == 1)
            print_histogram(histogram, name);
        break;

        case 8:  /* perform edge detection */
           printf("\nCIPS> Enter input image name\n");
           get_image_name(name);
           printf("\nCIPS> Enter output image name\n");
           get_image_name(name2);
           get_parameters(&il, &ie, &ll, &le);
           get_edge_options(&detect_type, &detect_threshold,
                            &high);
           if(detect_type == 4)
              quick_edge(name, name2, the_image, out_image,
                         il, ie, ll, le, detect_threshold,
                         high);
           else
              detect_edges(name, name2, the_image, out_image,
                           il, ie, ll, le, detect_type,
                           detect_threshold, high);
         break;


        case 20:  /* exit system */
         not_finished = 0;
        break;

        default:
         printf("\nCould not understand response, try again");
        break;

     }               /* ends switch response          */
  }               /* ends while not finished */
}               /* ends main                  */




   /******************************************************
   *
   *   clear_text_screen()
   *
   *   This calls Microsoft C functions to clear the text
   *   screen and set a blue background with gray text.
   *
   *******************************************************/


clear_text_screen()
{
   _setvideomode(_TEXTC80);      /* MSC 6.0 statements */
   _setbkcolor(1);
   _settextcolor(7);
   _clearscreen(_GCLEARSCREEN);
}  /* ends clear_text_screen */




   /******************************************************
   *
   *   show_image(...
   *
   *   This function displays the image numbers on the
   *   screen as text.  It displays 20 rows  with 18
   *   columns each.
   *
   *******************************************************/

show_image(image, il, ie)
   int   il, ie;
   short image[ROWS][COLS];
{
   int i, j;
   printf("\n   ");
   for(i=0; i<18; i++)
      printf("-%3d", i+ie);

   for(i=0; i<20; i++){
      printf("\n%2d>", i+il);
      for(j=0; j<18; j++)
         printf("-%3d", image[i][j]);
   }

   printf("\nPress enter to continue");
   get_integer(&i);

}  /* ends show_image  */





   /******************************************************
   *
   *   show_menu(..
   *
   *   This function displays the CIPS main menu.
   *
   *******************************************************/
show_menu()
{

        printf("\n\n\nWelcome to CIPS");
        printf("\nThe C Image Processing System");
        printf("\nThese are you choices:\n");
        printf("\n\t1.  Display image header");
        printf("\n\t2.  Show image numbers");
        printf("\n\t3.  Print image numbers");
        printf("\n\t4.  Display image (VGA & EGA only)");
        printf("\n\t5.  Display or print image using halftoning");
        printf("\n\t6.  Print graphics image using dithering");
        printf("\n\t7.  Print or display histogram numbers");
        printf("\n\t8.  Perform edge detection");
        printf("\n\t20. Exit system");
        printf("\n\nEnter choice _\b");

}    /* ends show_menu */
